"use client";

import { useState, useEffect } from "react";
import { collection, addDoc, query, orderBy, limit, onSnapshot } from "firebase/firestore";
import { db } from "@/lib/firebase";
import { Activity } from "@/lib/types";

export const useActivity = () => {
  const [activities, setActivities] = useState<Activity[]>([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    const activitiesRef = collection(db, "activities");
    const q = query(activitiesRef, orderBy("date", "desc"), limit(10));

    const unsubscribe = onSnapshot(q, (snapshot) => {
      try {
        const activityList = snapshot.docs.map(doc => ({
          id: doc.id,
          ...doc.data()
        })) as Activity[];
        
        setActivities(activityList);
        setLoading(false);
      } catch (err) {
        console.error("Error fetching activities:", err);
        setError("Failed to fetch activities");
        setLoading(false);
      }
    }, (err) => {
      console.error("Error setting up activities listener:", err);
      setError("Failed to listen to activities updates");
      setLoading(false);
    });

    return () => unsubscribe();
  }, []);

  const addActivity = async (activity: Omit<Activity, "id">) => {
    try {
      const docRef = await addDoc(collection(db, "activities"), {
        ...activity,
        date: new Date().toISOString()
      });
      return { id: docRef.id, ...activity };
    } catch (err) {
      console.error("Error adding activity:", err);
      throw err;
    }
  };

  return {
    activities,
    loading,
    error,
    addActivity
  };
};